package de.wfink.ejb2.examples.cmp;

import java.util.logging.Logger;

import javax.ejb.CreateException;
import javax.ejb.EJBException;
import javax.ejb.SessionContext;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import de.wfink.ejb2.examples.cmp.mapper.MapperCMPEntityLocal;
import de.wfink.ejb2.examples.cmp.mapper.MapperCMPEntityLocalHome;
import de.wfink.ejb2.examples.cmp.mapper.SimpleEnum;

/**
 * @ejb.bean name="MapperCMPSession" display-name="Simple CMP Session bean" description="A SeesionBean as simple CMP mapper example"
 *           jndi-name="ejb21/MapperCMPSession" local-jndi-name="ejb21/MapperCMPSession" type="Stateless" view-type="both"
 * 
 * @ejb.home local-class="de.wfink.ejb2.examples.cmp.MapperCmpSessionLocalHome"
 *           remote-class="de.wfink.ejb2.examples.cmp.MapperCmpSessionHome"
 * @ejb.interface local-class="de.wfink.ejb2.examples.cmp.MapperCmpSessionLocal"
 *                remote-class="de.wfink.ejb2.examples.cmp.MapperCmpSession"
 * 
 * @jboss.clustered cluster="false" //jboss.container-configuration name="Standard Stateless SessionBean"
 * 
 * @ejb.ejb-ref ejb-name="MapperCMPEntity" ref-name="local/MapperCMPEntity" view-type="local"
 * 
 */
public class MapperCmpSessionBean implements javax.ejb.SessionBean {
    private static final Logger LOG = Logger.getLogger(MapperCmpSessionBean.class.getName());

    /**
     * Session context will be set from lifecycle method
     */
    private SessionContext sessionContext;
    /**
     * Hold a reference to the Entity home interface
     */
    private MapperCMPEntityLocalHome cmpEntityHome;

    public void setSessionContext(SessionContext sessionContext) throws EJBException {
        LOG.info("=> set Context");
        this.sessionContext = sessionContext;
        try {
            this.cmpEntityHome = (MapperCMPEntityLocalHome)new InitialContext().lookup("java:comp/env/local/MapperCMPEntity");
        } catch (NamingException e) {
            throw new EJBException("Failed to lookup the ejb-ref 'local/MapperCMPEntity'", e);
        }
    }
    
    public void ejbActivate() throws EJBException {
        LOG.info("ACTIVATE");
    }

    public void ejbPassivate() throws EJBException {
        LOG.info("PASSIVATE");
    }

    public void ejbRemove() throws EJBException {
        LOG.info("REMOVE");
    }

    public void ejbCreate() throws CreateException {
        LOG.info("CREATE");
    }

    /**
     * Business method to create a SimpleEntity.
     * 
     * @ejb.interface-method view-type = "both"
     * @ejb.transaction type = "Supports"
     */
    public void createEntity(Long pkey) {
        LOG.finer("Start");
        try {
            this.cmpEntityHome.create(pkey, "The first entity", SimpleEnum.TYPE2);
        } catch (Exception e) {
            throw new EJBException("Creation of SimpleEntity failed!", e);
        }
        LOG.finer("Entity created!");
    }

    /**
     * Business method to create a SimpleEntity.
     * 
     * @ejb.interface-method view-type = "remote"
     * @ejb.transaction type = "Required"
     */
    public String getEntityName(Long pkey) {
        LOG.finer("Start");
        try {
            MapperCMPEntityLocal entity = this.cmpEntityHome.findByPrimaryKey(pkey);
            LOG.info("Entity readed  name=" + entity.getName() + "type= " + entity.getType());
            return (entity.getName());
        } catch (Exception e) {
            throw new EJBException("Read of SimpleEntity [" + pkey + "] failed!", e);
        }
    }

    /**
     * Business method to remove a SimpleEntity.
     * 
     * @ejb.interface-method view-type = "both"
     * @ejb.transaction type = "Supports"
     */
    public void removeEntity(Long pkey) {
        LOG.finer("Start");
        try {
            this.cmpEntityHome.findByPrimaryKey(pkey).remove();
        } catch (Exception e) {
            throw new EJBException("Remove of SimpleEntity failed! Entity PKey=" + pkey + " not found", e);
        }
        LOG.finer("Entity pkey=" + pkey + " removed!");
    }
}
