package de.wfink.ejb2.examples.cmp.mapper;

import java.util.logging.Level;
import java.util.logging.Logger;

import javax.ejb.CreateException;
import javax.ejb.EntityBean;
import javax.ejb.EntityContext;
import javax.ejb.RemoveException;

/**
 *
 * EJB CMP bean as simple implementation.
 *
 *
 * @author "<a href=\"mailto:WolfDieter.Fink@gmail.com\">Wolf-Dieter Fink</a>"
 *
 * @ejb.bean name="MapperCMPEntity" display-name="MapperCMPEntity" local-jndi-name="ejb21/MapperCMPEntity" view-type="local"
 *           type="CMP" cmp-version="2.x" primkey-field="id"
 * @ejb.home local-class="de.wfink.ejb2.examples.cmp.mapper.MapperCMPEntityLocalHome"
 * @ejb.interface local-class="de.wfink.ejb2.examples.cmp.mapper.MapperCMPEntityLocal"
 * ejb.persistence table-name="MAPPER_ENTITY"
 * @ejb.transaction type="Required"
 *
 * @ejb.finder signature="de.wfink.ejb2.examples.cmp.mapper.MapperCMPEntityLocal findById(java.lang.Long id)"
 *             query="SELECT OBJECT(o) FROM MapperCMPEntity o WHERE o.id=?1"
 */
public abstract class MapperCMPEntityBean implements EntityBean {
    private static final long serialVersionUID = 1L;
    private static final Logger LOG = Logger.getLogger(MapperCMPEntityBean.class.getName());
    
    private EntityContext context;

  /**
   * EJB callback will be called if the bean is activated from pool
   */
  public void ejbActivate() {
  	LOG.info("ACTIVATE PKey="+this.context.getPrimaryKey());
  }

  /**
   * EJB callback will be called after the CMP bean was loaded from the data store
   */
  public void ejbLoad() {
  	LOG.info("LOAD PKey="+this.context.getPrimaryKey());
  }

  /**
   * EJB callback will be called before the bean is passivated and returned to pool
   */
  public void ejbPassivate() {
  	LOG.info("PASSIVATE PKey="+this.context.getPrimaryKey());
  }

  /**
   * EJB callback will be called before the CMP bean is removed from data store
   */
  public void ejbRemove() throws RemoveException {
  	LOG.info("REMOVE PKey="+this.context.getPrimaryKey());
  }

  /**
   * EJB callback will be called before the CMP bean is stored to the data store
   */
  public void ejbStore() {
  	LOG.info("STORE PKey="+this.context.getPrimaryKey());
  }

  public void setEntityContext(EntityContext context) {
  	LOG.info("SET CONTEXT");
  	this.context = context;
  }

  public void unsetEntityContext() {
  	LOG.info("UNSET CONTEXT");
  	this.context = null;
  }

  public Long ejbCreate() throws CreateException {
    LOG.info("CREATE");
    return (null);
  }

  public void ejbPostCreate() {
    LOG.info("POSTCREATE");
  }

  /**
   * Invoked by the container when the create method is called on the home
   * interface.
   *
   * @param id         The value of the primary key property.
   * @param name       The given name of the object
   * @param timestamp  The creation time, if not set the current time is used
   *
   * @ejb.create-method view-type="local"
   * @ejb.transaction type = "RequiresNew"
   */
  public Long ejbCreate(Long id,String name, SimpleEnum type) throws CreateException {
    LOG.info("CREATE id="+id+" name="+name+" type="+type);
    setId(id);
    setName(name);
    setType(type);
    return (null);
  }

  public void ejbPostCreate(Long id,String name, SimpleEnum type) {
  }


  /**
   * @ejb.persistence
   * @ejb.interface-method
   */
  public abstract Long getId();
	

  /**
   * @ejb.interface-method
   */
  public abstract void setId(Long id);

  /**
   * @ejb.persistence
   * @ejb.interface-method
   */
  public abstract String getName();

  /**
   * @ejb.interface-method
   */
  public abstract void setName(String name);

  /**
   * @ejb.persistence
   * @jboss.column-name name="cre_timestamp"
   * @ejb.interface-method
   */
  public abstract SimpleEnum getType();

  /**
   * Method will not be shown in the interface to preserve changes
   */
  public abstract void setType(SimpleEnum type);

  /**
    * @ejb.interface-method
  */
  public void showStack() {
  	LOG.log(Level.FINEST, "SHOW STACKTRACE", new Exception("SHOW STACKTRACE"));
  }

}
