package de.wfink.ejb2.examples.cmp.mapper;

import java.util.Date;

import org.jboss.as.cmp.jdbc.Mapper;
import org.jboss.logging.Logger;


/**
 * Customized mapper to convert a custom object to plain supported java type.
 * This is a simple example that store a {@link Date} as integer
 *  
 * @author Wolf-Dieter Fink
 */
public final class SimpleEnumDbMapper implements Mapper {
	private static final Logger LOGGER = Logger.getLogger(SimpleEnumDbMapper.class);
	
  /**
   * Mapping configured within the jbosscmp-jdbc.xml descriptor of the persistence archive.
   * Convert a user type to a plain supported type.
   * 
   * @param fieldValue the object to convert
   * @return a simple String for persistence container
   */
	public Object toColumnValue(Object fieldValue) {
		Object columnValue = fieldValue == null ? null : ((SimpleEnum)fieldValue).toString();
		LOGGER.info("toColumn " + columnValue);
		return columnValue;
  }

  /**
   * Mapping configured within the jbosscmp-jdbc.xml descriptor of the persitence archive.
   * Convert a plain java type to a specific user type.
   * 
   * @param columnValue {@link java.sqlTimestamp} read from persistence container
   * @return the custom object
   */
  public Object toFieldValue(Object columnValue) {
    try {
    	final Object fieldValue;
    	
      if(columnValue == null) {
        fieldValue = null;
      }else {
        fieldValue = SimpleEnum.valueOf((String)columnValue);
      }
  		LOGGER.info("toField " + fieldValue);
  		return fieldValue;
    }catch(ClassCastException e) {
      String className = (columnValue != null) ? columnValue.getClass().getName() : "null";
      throw new IllegalArgumentException("Illegal mapping, only String supported but was ("+className+")"+columnValue,e);
    }
  }

}
